==> haskell-dav-1.3.3-39-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DAV
version: 1.3.3
id: DAV-1.3.3-3UbQf93uaBU3CmqOTEkbwh
key: DAV-1.3.3-3UbQf93uaBU3CmqOTEkbwh
license: GPL-3.0-only
copyright: Copyright (C) 2012-2018  Clint Adams
maintainer: clint@debian.org
author: Clint Adams
homepage: http://floss.scru.org/hDAV
synopsis: RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.
    .
    In addition, there is an executable, hdav, which can be used for
    command-line operation.
category: Web
abi: ab46365ffd750354d7ef8b55880e1f7d
exposed: True
exposed-modules:
    Network.Protocol.HTTP.DAV
hidden-modules: Network.Protocol.HTTP.DAV.TH
import-dirs: /usr/lib/ghc-8.6.4/site-local/DAV-1.3.3
library-dirs: /usr/lib/ghc-8.6.4/site-local/DAV-1.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/DAV-1.3.3
hs-libraries: HSDAV-1.3.3-3UbQf93uaBU3CmqOTEkbwh
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu containers-0.6.0.1
    data-default-0.7.1.1-GPAEdZkaAwALFGM1Pbeyt4
    exceptions-0.10.1-7EeRXpdm0c5D9yRsXefkxH
    http-client-0.6.4-4eignF5HylU2BUpoDKITVq
    http-client-tls-0.3.5.3-ENbOqCF0gxIB9PpdQY137f
    http-types-0.12.3-D3aEnVjdeLuS27pc1eWXD
    lens-4.17-9007cpgFhetJxFTlfQo2qw mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-F1E9AxVLoHK4gnfKIcTrBt
    transformers-compat-0.6.4-3mIoeQKAFq789cuQC8bUpt
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    xml-conduit-1.8.0.1-9wp2HtsM76K40XJY1W2Mml
    xml-hamlet-0.5.0-4zwktHpKY3WH3lADX1E2OQ
haddock-interfaces: /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html: /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dav-1.3.3-40-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DAV
version: 1.3.3
id: DAV-1.3.3-ErL7hjsy9HY6rxwyUcmIfN
key: DAV-1.3.3-ErL7hjsy9HY6rxwyUcmIfN
license: GPL-3.0-only
copyright: Copyright (C) 2012-2018  Clint Adams
maintainer: clint@debian.org
author: Clint Adams
homepage: http://floss.scru.org/hDAV
synopsis: RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.
    .
    In addition, there is an executable, hdav, which can be used for
    command-line operation.
category: Web
abi: 1aef45728d8a40b850218ee85fef8b5d
exposed: True
exposed-modules:
    Network.Protocol.HTTP.DAV
hidden-modules: Network.Protocol.HTTP.DAV.TH
import-dirs: /usr/lib/ghc-8.6.5/site-local/DAV-1.3.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/DAV-1.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/DAV-1.3.3
hs-libraries: HSDAV-1.3.3-ErL7hjsy9HY6rxwyUcmIfN
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu containers-0.6.0.1
    data-default-0.7.1.1-GPAEdZkaAwALFGM1Pbeyt4
    exceptions-0.10.1-7EeRXpdm0c5D9yRsXefkxH
    http-client-0.6.4-DCmpgbT5KA3LBdEx9Lt28S
    http-client-tls-0.3.5.3-59gffMozZgrJS4tvjSII2O
    http-types-0.12.3-FkUAYjCWW0WBZI2lM6bGTd
    lens-4.17-KviXglNeqUtLtDpQmaOU3Y mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-F1E9AxVLoHK4gnfKIcTrBt
    transformers-compat-0.6.4-3mIoeQKAFq789cuQC8bUpt
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    xml-conduit-1.8.0.1-5BLQNM5qacD158eSPiGvla
    xml-hamlet-0.5.0-7LqlEJX9yHX6Ve2nsSXkMi
haddock-interfaces: /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html: /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
